# This file is auto-generated by hatch-gradle-version. Do not edit.

GRADLE_VERSION = "1.0.1.1.20.1"
FULL_VERSION = "1.0.1.1.20.1.1.0"

CURSEFORGE_ID = "1239463"
JETBRAINS_ANNOTATIONS_VERSION = "23.0.0"
KOTLIN_STDLIB_DEFAULT_DEPENDENCY = "false"
MAVEN_GROUP = "gay.object.ioticblocks"
MINECRAFT_VERSION = "1.20.1"
MOD_ID = "ioticblocks"
MOD_VERSION = "1.0.1"
MODRINTH_ID = "u3PPsXzt"
ORG_GRADLE_JVMARGS = "-Xmx4096M"
ORG_JETBRAINS_DOKKA_EXPERIMENTAL_GRADLE_PLUGIN_MODE = "V2Enabled"
ORG_JETBRAINS_DOKKA_EXPERIMENTAL_GRADLE_PLUGIN_MODE_NO_WARN = "true"
